.. image:: https://img.shields.io/pypi/v/jaraco.text.svg
   :target: https://pypi.org/project/jaraco.text

.. image:: https://img.shields.io/pypi/pyversions/jaraco.text.svg

.. image:: https://img.shields.io/pypi/dm/jaraco.text.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.text/master.svg
   :target: http://travis-ci.org/jaraco/jaraco.text
